@@ -7,7 +7,7 @@ beta[1,]=as.vector(mod$coeff[,1])
 Sigma2=as.matrix(mod$cov.unscaled)
 for (i in 2:niter)
 {
-tildebeta=mvrnorm(1,beta[i-1,],scale*Sigma2)
+tildebeta=rmnorm(1,beta[i-1,],scale*Sigma2)
 llr=loglinnoinflpost(tildebeta,y,X)-loglinnoinflpost(beta[i-1,],y,X)
 if (runif(1)<=exp(llr)) beta[i,]=tildebeta else beta[i,]=beta[i-1,]
 }
